@@ -1,6 +1,8 @@
 """ InfluxDB Singleton Class """
 from influxdb import InfluxDBClient
-
+import os
+from dotenv import load_dotenv
+load_dotenv()
 class InfluxDBLog:  
     singleton = None 
     client_influxDB = None 
@@ -11,11 +13,11 @@ class InfluxDBLog:
         return cls.singleton  
 
     def __init__(self):
-        self.client_influxDB = InfluxDBClient("server.trollhunter.guru",
-                                                8086,
-                                                "instapy",
-                                                "password",
-                                                "instapy")
+        self.client_influxDB = InfluxDBClient(os.getenv("INFLUXDB_SERVER"),
+                                                os.getenv("INFLUXDB_PORT"),
+                                                os.getenv("INFLUXDB_USERNAME"),
+                                                os.getenv("INFLUXDB_PASSWORD"),
+                                                os.getenv("INFLUXDB_DB"))
 
 
     def addEntry(self, measurement, tag_name, tag_value, field1_name, field1_value):
